@@ -30,7 +30,7 @@ public delegate void FirstFindHandler();
 public interface IFinder
 {
 	IFindStrategy Strategy { get; set; }
-			Range LastFound { get; set; }
+			Util.Range LastFound { get; set; }
 
 
 					event FirstFindHandler FirstFind;
@@ -41,4 +41,4 @@ public interface IFinder
 	IAsyncResult ReplaceAll(byte[] ba, AsyncCallback ac);
 }
 
-} // end namespace
\ No newline at end of file
+} // end namespace
